OnceLock

Struct OnceLock 

pub struct OnceLock<T> { /* private fields */ }
A wrapper around a OnceCell that implements Collect.

Only provides safe read access to the wrapped OnceCell, full write access requires unsafety.

If the OnceLock is directly held in a Gc pointer, safe mutable access is provided, since methods on Gc can ensure that the write barrier is called.

Implementations

Source

impl<T> OnceLock<T>

pub fn new() -> Self

pub fn get(&self) -> Option<&T>

pub fn get_mut(&mut self) -> Option<&mut T>